﻿/*********************************************************************************************************************************************************
*  Script : BT_inside_Tout_MZ "Affichage des informations des Systèmes Tactiques des Bricol'Trolls sur la page de Vue de MountyHall"                     *
*  Compatibilité : encodage UTF-8 (Greasemonkey)                                                                                                         *
*  Pré-requis : nécessite l'utilisation du script BT_inside_MZ.user.js pour Greasemonkey                                                                 *
*  Auteur : Vapulabehemot (82169)                                                                                                                        *
*  Version : 2.0.1 (08/07/2019) adaptation à la nouvelle structure de la page de Vue MH et de Tout_MZ.user.js                                            *
*  Historique : 2.0.0 (10/12/2016) adaptation pour fonctionner avec le script Tout_MZ.user.js pour Greasemonkey au lieu d'être un script externe dans MZ *
*               1.1.1 (13/07/2015) adaptation à la nouvelle structure de la page de Vue MH                                                               *
*               1.1.0 (12/07/2013) gestion de multiples Systèmes Tactiques                                                                               *
*               1.0.0 (07/07/2013) gestion des Suivants du Système Tactique                                                                              *
*               0.1.0 (29/06/2013) gestion des Trolls du Système Tactique                                                                                *
*               0.0.1 (08/06/2013)                                                                                                                       *
*********************************************************************************************************************************************************/


// ==UserScript==
// @name         MH - Vapulabehemot - BT_inside_Tout_MZ
// @namespace    MH
// @description  Affichage des informations des Systèmes Tactiques des Bricol'Trolls sur la page de Vue de MountyHall, version 2.0.0 du 10/12/2016, par Vapulabehemot (82169)
// @include      */mountyhall/MH_Play/Play_vue.php*
// @exclude      *smartphone*
// @icon         https://mz.mh.raistlin.fr/mz/img/mz_logo_small.png
// @version      2.0.1
// @grant        GM_getValue
// @grant        GM_deleteValue
// @grant        GM_setValue
// @injectframes 1
// ==/UserScript==


// *** PARAMETRAGE ***
// les valeurs seront automatiquement reprises de celles du script BT_inside_MZ.user.js
var dureeAffichageInfo;
var dureeInfoTrollsRecentes;
var dureeInfoTrollsAnciennes;
var dureeInfoTrollsPerimees;
var dureeInfoSuivantsRecentes;
var dureeInfoSuivantsAnciennes;
var dureeInfoSuivantsPerimees;
var urlIconeAffichageInfo;
var urlIconeInfoRecentes;
var urlIconeInfoAnciennes;
var urlIconeInfoPerimees;
var urlIconeVisibilite;
var couleurJouable;
var couleurNonJouable;
var couleurLigneTrolls;
var couleurLigneTrollsHorsVue;
var couleurLigneSuivantsPerso;
var couleurLigneSuivants;

// *** CONSTANTES GLOBALES ***
var distanceMax;

// *** VARIABLES GLOBALES ***
var trollsDesST = new Array;
var suiteSTaccessibles = '';
var suivantsDesST = new Array;
var fenetreInfo;


/* Utilisation de la gestion de l'enregistrement des données de GreaseMonkey, avec partage entre scripts via le localStorage, par Vapulabehemot (82169) */
// Nécessite la présence de @grant GM_getValue, @grant GM_deleteValue et @grant GM_setValue
function MY_getValue(key) {
	if ((GM_getValue(key) == null)
		|| (window.localStorage.getItem(key) != null && window.localStorage.getItem(key) != GM_getValue(key))){
		try {
			GM_setValue(key, JSON.parse(window.localStorage.getItem(key)));
		}
		catch(e) {
			GM_setValue(key, window.localStorage.getItem(key));
		}
	}
	return GM_getValue(key);
}
function MY_removeValue(key) {
	GM_deleteValue(key);
	window.localStorage.removeItem(key);
}
function MY_setValue(key, val) {
	GM_setValue(key, val);
	window.localStorage[key] = val;
}

// définition des variables et fonctions Tout_MZ manquantes
if (typeof numTroll === 'undefined') {
	if (MY_getValue('NUM_TROLL')) {
		// récupération de la valeur sauvegadré par le script Tout_MZ
		var numTroll = MY_getValue('NUM_TROLL');
	}
	else {
		// ou bien détéction dans la page
		var texte = document.getElementById('titre2').parentNode.innerHTML;
		var numTroll = texte.match(/ai_IdPJ(.*)type/)[0].match(/(\d+)/)[0];		
	}
}
if (typeof getSortComp !== 'function') {
	// reprises des fonctions et variables de Tout_MZ
	function getSortComp(nom,niveau) {
		return getTalent(nom,niveau);
	}
	var arrayTalents = {
						/* Compétences */
						'Acceleration du Metabolisme':'AM',
						'Attaque Precise':'AP',
						'Balayage':'Balayage',
						//'Balluchonnage':'Ballu',
						'Baroufle':'Baroufle',
						'Bidouille':'Bidouille',
						'Botte Secrete':'BS',
						'Camouflage':'Camou',
						'Charger':'Charger',
						'Connaissance des Monstres':'CdM',
						'Construire un Piege':'Piege',
						'Piege a Feu':'PiegeFeu',
						'Piege a Glue':'PiegeGlue',
						'Contre-Attaquer':'CA',
						'Coup de Butoir':'CdB',
						'Course':'Course',
						'Deplacement Eclair':'DE',
						'Dressage':'Dressage',
						'Ecriture Magique':'EM',
						'Frenesie':'Frenesie',
						'Golemologie':'Golemo',
						'Golem de cuir':'GolemCuir',
						'Golem de metal':'GolemMetal',
						'Golem de mithril':'GolemMithril',
						'Golem de papier':'GolemPapier',
						'Grattage':'Grattage',
						'Hurlement Effrayant':'HE',
						'Identification des Champignons':'IdC',
						'Insultes':'Insultes',
						'Lancer de Potions':'LdP',
						'Marquage':'Marquage',
						'Melange Magique':'Melange',
						'Miner':'Miner',
						'Necromancie':'Necro',
						'Painthure de Guerre':'PG',
						'Parer':'Parer',
						'Pistage':'Pistage',
						'Planter un Champignon':'PuC',
						'Regeneration Accrue':'RA',
						'Reparation':'Reparation',
						'Retraite':'Retraite',
						'Rotobaffe':'RB',
						'Shamaner':'Shamaner',
						"S'interposer":'SInterposer',
						'Tailler':'Tailler',
						//'Vol':'Vol',
						/* Sortilèges */
						'Analyse Anatomique':'AA',
						'Armure Etheree':'AE',
						'Augmentation de l´Attaque':'AdA',
						'Augmentation de l´Esquive':'AdE',
						'Augmentation des Degats':'AdD',
						'Bulle Anti-Magie':'BAM',
						'Bulle Magique':'BuM',
						'Explosion':'Explo',
						'Faiblesse Passagere':'FP',
						'Flash Aveuglant':'FA',
						'Glue':'Glue',
						'Griffe du Sorcier':'GdS',
						'Hypnotisme':'Hypno',
						'Identification des tresors':'IdT',
						'Invisibilite':'Invi',
						'Levitation':'Levitation',
						'Precision Magique':'PreM',
						'Projectile Magique':'Projo',
						'Projection':'Proj',
						'Puissance Magique':'PuM',
						'Rafale Psychique':'Rafale',
						'Sacrifice':'Sacro',
						'Siphon des Ames':'Siphon',
						'Telekinesie':'Telek',
						'Teleportation':'TP',
						'Vampirisme':'Vampi',
						'Vision Accrue':'VA',
						'Vision lointaine':'VL',
						'Voir le Cache':'VlC',
						'Vue Troublee':'VT'
						//'':''
						};

	function epure(texte) {
		return texte.replace(/[àâä]/g,'a')
					.replace(/Â/g,'A')
					.replace(/[ç]/g,'c')
					.replace(/[éêèë]/g,'e')
					.replace(/[ïî]/g,'i')
					.replace(/[ôöõ]/g,'o')
					.replace(/[ùûü]/g,'u');
	}									
	function getTalent(nom,niveau) {
		var nomEnBase = arrayTalents[epure(nom)];
		if(!nomEnBase) return 0;
		if(!niveau) var niveau = '';
		if(MY_getValue(numTroll+'.talent.'+nomEnBase+niveau))
			return MY_getValue(numTroll+'.talent.'+nomEnBase+niveau);
		return 0;
	}
}
if (typeof appendText !== 'function') {
	// reprise de la fonction de Tout_MZ
	function appendText(paren,text,bold) {
		if(bold) {
			var b = document.createElement('b');
			b.appendChild(document.createTextNode(text));
			paren.appendChild(b);
		}
		else {
			paren.appendChild(document.createTextNode(text));
		}
	}	
}
if (typeof checkBoxDiplo === 'undefined') {
	// détection dans la page
	if (document.getElementById('delDiplo')) {
		var checkBoxDiplo = document.getElementById('delDiplo');
	}
	else {
		var checkBoxDiplo = null;
	}
}
if (typeof checkBoxLevels === 'undefined') {
	// détection dans la page
	if (document.getElementById('delniveau')) {
		var checkBoxLevels = document.getElementById('delniveau');
	}
	else {
		var checkBoxLevels = null;
	}
}
if (typeof isDiploRaw === 'undefined') {
	// par défaut à false
	var isDiploRaw = false;
}	
if (typeof x_monstres === 'undefined') {
	// détection dans la page (reprise du code de Tout_MZ)
	var node = document.getElementById('mh_vue_hidden_monstres');
	this['tr_monstres'] = node.getElementsByTagName('tr');
	this['nbMonstres'] = this['tr_monstres'].length-1;
	var x_monstres = this['tr_monstres'];
}




// *** Procédure principale exécutée sur la page de Vue de MountyHall ***
if ( window.self.location.toString().indexOf('/MH_Play/Play_vue.php') != -1 ) {
	try {

		if ( window.localStorage.BT_inside_MZ_constantes == null ) {	
			window.alert('Le script BT_inside_Tout_MZ.user.js nécessite l\'utilisation du script BT_inside_MZ.user.js pour fonctionner');
		}
		else {
			// détection dans la page des numéros d'ordre des colonnes 
			var colonnesDesEntites = 	[	['Distance', 'Actions', 'Reference', 'Niveau', 'Nom', 'X', 'Y', 'N'],
											['Distance', 'Actions', 'Reference', 'Nom', 'Niveau', 'Race', 'PV', 'PA', 'Guilde', 'X', 'Y', 'N'],
											['Distance', 'Actions', 'Reference', 'Type', 'X', 'Y', 'N'],
											['Distance', 'Actions', 'Champignon', 'X', 'Y', 'N'],
											['Distance', 'Actions', 'Reference', 'Nom', 'X', 'Y', 'N'],
											['Distance', 'Actions', 'Reference', 'Type', 'X', 'Y', 'N']
										];
							
			var structureDesEntites = 	[	['Monstres', 'mh_vue_hidden_monstres', 'Dist.', 'Actions', 'Réf.', 'Niv.', 'Nom', 'X<', 'Y<', 'N<'],
											['Trolls', 'mh_vue_hidden_trolls', 'Dist.', 'Actions', 'Réf.', 'Nom', 'Niv.', 'Race', 'PV', 'PA', 'Guilde', 'X<', 'Y<', 'N<'],
											['Tresors', 'mh_vue_hidden_tresors', 'Dist.', 'Actions', 'Réf.', 'Type', 'X<', 'Y<', 'N<'],
											['Champignons', 'mh_vue_hidden_champignons', 'Dist.', 'Actions', 'Champignon', 'X<', 'Y<', 'N<'],
											['Lieux', 'mh_vue_hidden_lieux', 'Dist.', 'Actions', 'Réf.', 'Nom', 'X<', 'Y<', 'N<'],
											['Cenotaphes', 'mh_vue_hidden_cadavres', 'Dist.', 'Actions', 'Réf.', 'Type', 'X<', 'Y<', 'N<']
										];

			var indexDesColonnes = 		{	Monstres: {Distance: -1, Actions: -1, Reference: -1, Niveau: -1, Nom: -1, X: -1, Y: -1, N: -1},
											Trolls: {Distance: -1, Actions: -1, Reference: -1, Nom: -1, Niveau: -1, Race: -1, PV: -1, PA: -1, Guilde: -1, X: -1, Y: -1, N: -1},
											Tresors: {Distance: -1, Actions: -1, Reference: -1, Type: -1, X: -1, Y: -1, N: -1}, 
											Champignons: {Distance: -1, Actions: -1, Champignon: -1, X: -1, Y: -1, N: -1},
											Lieux: {Distance: -1, Actions: -1, Nom: -1, X: -1, Y: -1, N: -1},
											Cenotaphes: {Distance: -1, Actions: -1, Type: -1, X: -1, Y: -1, N: -1}
										};
								
			// pour chacune des entités
			for (var i=0;i<structureDesEntites.length;i++) {
				// récupération de tous les titres de colonnes
				var titresColonnes = document.getElementById(structureDesEntites[i][1]).getElementsByTagName('thead')[0].querySelectorAll('th, td');
				// pour chacune des colonnes
				for (var j=0;j<titresColonnes.length;j++) {
					// pour chacune des colonnes recherchés
					for (var k=2;k<structureDesEntites[i].length;k++) {
						if (titresColonnes[j].outerHTML.indexOf(structureDesEntites[i][k]) != -1) {
							// détection de la colonne recherchée : sauvegarde de son numéro d'ordre	
							indexDesColonnes[structureDesEntites[i][0]][colonnesDesEntites[i][k-2]] = j;
						}
					}
				}
			}


			
			// récupération des valeurs des constantes depuis le localStorage
			var listeConstantes = window.localStorage.BT_inside_MZ_constantes.split(';');
			// constantes modifiables
			dureeAffichageInfo = listeConstantes[0];
			dureeInfoTrollsRecentes = listeConstantes[1];
			dureeInfoTrollsAnciennes = listeConstantes[2];
			dureeInfoTrollsPerimees = listeConstantes[3];
			dureeInfoSuivantsRecentes = listeConstantes[4];
			dureeInfoSuivantsAnciennes = listeConstantes[5];
			dureeInfoSuivantsPerimees = listeConstantes[6];
			urlIconeAffichageInfo = listeConstantes[7];
			urlIconeInfoRecentes = listeConstantes[8];
			urlIconeInfoAnciennes = listeConstantes[9];
			urlIconeInfoPerimees = listeConstantes[10];
			urlIconeVisibilite = listeConstantes[11];
			couleurJouable = listeConstantes[12];
			couleurNonJouable = listeConstantes[13];
			couleurLigneTrolls = listeConstantes[14];
			couleurLigneTrollsHorsVue = listeConstantes[15];
			couleurLigneSuivantsPerso = listeConstantes[16];
			couleurLigneSuivants = listeConstantes[17];
			// constantes globales
			distanceMax = listeConstantes[18];

			
			
			// compile si nécessaire les informations des Trolls récupérées depuis les Systèmes Tactiques des Bricol'Trolls et vérifie la présence de la zone d'affichage des Trolls (c'est-à-dire pas d'effet Oukisont de Fumeux)
			if ( compileInformationsTrollsBT(numTroll) && document.getElementById('mh_vue_hidden_trolls') != null ) {
				// récupération des Trolls dans la Vue (indiqués par MountyHall ou insérés précédemment par le script BT_inside_MZ.user.js)
				x_trolls = document.getElementById('mh_vue_hidden_trolls').getElementsByTagName('tr');
				nbTrolls = x_trolls.length-1;
				
				// ajout d'un écouteur d'événement sur le bouton "Envoyer..." pour pouvoir appliquer le style des lignes lors de l'affichage de la colonne de cases à cocher 						
				if (document.getElementById('btnEnvoi')) {
					document.getElementById('btnEnvoi').addEventListener('click', onClickSend, true);
				}
				
				// ajout dans la vue MountyHall des informations compilées
				for (var i=0;i<trollsDesST.length;i++) {
					for (var j=1;j<x_trolls.length;j++) {
						if ( trollsDesST[i].Reference == x_trolls[j].childNodes[indexDesColonnes.Trolls.Reference].innerHTML ) {
							// ajout du marquage du TR comme étant modifié par le script BT_inside (ce marquage est utilisé pour appliquer le style des lignes de Troll des Systèmes Tactiques)
							if ( !x_trolls[j].firstChild.getAttribute('origine') ) {
								x_trolls[j].firstChild.setAttribute('cible', 'BT_inside');
								// le Troll est dans la Vue envoyée par MountyHall
								var texteVisibilite = '';
								// si le Troll connecté ne possède pas "Voir le caché" et que le Troll des Systèmes Tactiques est dans sa Vue MountyHall mais à une position différente de celle indiquée sur le site des Bricol'Troll, alors il ne faut pas tenir compte de la Visibilité 
								if ( getSortComp('Voir le Caché') == 0 && ( x_trolls[j].lastChild.previousSibling.previousSibling.innerHTML != trollsDesST[i].X || x_trolls[j].lastChild.previousSibling.innerHTML != trollsDesST[i].Y || x_trolls[j].lastChild.innerHTML != trollsDesST[i].N ) ) {
									trollsDesST[i].Visibilite = '';
								}
							}
							else {
								// le Troll n'est pas dans la Vue envoyée par MountyHall
								var texteVisibilite = '<font size="1">[hors-vue]</font>'
							}
							// Pour les Trolls hors-vue dont les coordonnées ont été volontairement ignorées, il faut masquer les Distances et les coordonnées
							if ( x_trolls[j].firstChild.innerHTML.indexOf(distanceMax) != -1 ) {
								x_trolls[j].firstChild.style.fontSize = '0px';
								x_trolls[j].lastChild.previousSibling.previousSibling.style.fontSize = '0px';
								x_trolls[j].lastChild.previousSibling.style.fontSize = '0px';
								x_trolls[j].lastChild.style.fontSize = '0px';
							} 							
							// ajout de la fatigue en info-bulle sur la colonne Race
							x_trolls[j].childNodes[indexDesColonnes.Trolls.Race].title = trollsDesST[i].Fatigue;
							// ajout du Système Tactique utilisé en info-bulle sur la colonne Guilde
							x_trolls[j].childNodes[indexDesColonnes.Trolls.Guilde].firstChild.title = 'Système Tactique : ' + trollsDesST[i].SystemeTactique + ' ' + trollsDesST[i].NomGroupe;
							// ajout de l'information [hors-vue] dans la colonne Guilde pour les lignes insérées par le script BT_inside_MZ.user.js 
							var uneDiv = document.createElement('div');
							uneDiv.innerHTML = texteVisibilite;
							uneDiv.style.cssFloat = 'left'; // sur la même ligne, à la suite
							var uneAutreDiv = document.createElement('div');
							uneAutreDiv.style.cssFloat = 'right'; // sur la même ligne, collé à droite
							uneAutreDiv.appendChild(creerEspacement(1, 'left')); 
							uneAutreDiv.appendChild(uneDiv); 
							x_trolls[j].childNodes[indexDesColonnes.Trolls.Guilde].appendChild(uneAutreDiv);
							// ajout de l'information de visibilité dans la colonne Guilde (sauf pour les Trolls hors-vue dont les coordonnées ont été volontairement ignorées)
							if ( trollsDesST[i].Visibilite.length > 0 && x_trolls[j].firstChild.innerHTML.indexOf(distanceMax) == -1 ) {
								var uneImage = document.createElement('img');
								uneImage.src = urlIconeVisibilite;
								uneImage.title = trollsDesST[i].Visibilite;
								uneImage.align = 'left';
								uneImage.style.position = 'relative';
								uneImage.style.left = 3;
								x_trolls[j].childNodes[indexDesColonnes.Trolls.Guilde].lastChild.appendChild(uneImage); // .lastChild : la Div qui contient des informations insérées provenant des Systèmes Tactiques
							}
							// ajout de l'information concernant les PV si il n'y a pas de colonne PV (ou si le Troll ajouté par le script BT_inside_MZ.user.js est issu d'un Système Tactique qui n'est pas celui utilisé par MZ)
							if ( indexDesColonnes.Trolls.PV == -1 || !x_trolls[j].childNodes[indexDesColonnes.Trolls.PV].innerHTML) {
								// détermination des couleurs de la barre de PV en fonction de la date de mise à jour
								var couleurVide = '#FFFFFF'; // blanc
								var couleurPV = trollsDesST[i].CouleurBarrePV;
								if ( marqueurTemporel() - convertirDateEnMarqueurTemporel(trollsDesST[i].MAJ, ' ', '/') > dureeInfoTrollsPerimees * 3600 ) {
									couleurVide = '#D8D8D8'; // gris plus clair
									couleurPV = '#BDBDBD'; // gris plus foncé
								}
								// reprise/adaptation du code de MountyZilla utilisant les fonctions de MountyZilla
								/* cadre barre PV */
								var cadreBarrePV = document.createElement('div');
								cadreBarrePV.style.background = couleurVide; 
								cadreBarrePV.style.border = '1px solid black';
								cadreBarrePV.style.width = 100;
								cadreBarrePV.style.height = 10;
								cadreBarrePV.style.position = 'relative';
								cadreBarrePV.style.top = 2;
								cadreBarrePV.style.cssFloat = 'left'; // sur la même ligne, à la suite
								cadreBarrePV.title = trollsDesST[i].PV + ' PV le ' + trollsDesST[i].MAJ.replace(' ', ' à ');
								/* barre PV */
								var barrePV = document.createElement('div');
								barrePV.style.height = 10;
								barrePV.style.width = Math.floor(100 * Math.min(trollsDesST[i].PV.split('/')[0], trollsDesST[i].PV.split('/')[1]) / trollsDesST[i].PV.split('/')[1]);
								barrePV.style.background = couleurPV;
								barrePV.style.border = '1px solid black'
								barrePV.style.position = 'relative';
								barrePV.style.top = -1;
								barrePV.style.left = -1;
								cadreBarrePV.appendChild(barrePV);
								// ajout de la barre de PV dans la colonne "Guilde"
								x_trolls[j].childNodes[indexDesColonnes.Trolls.Guilde].lastChild.appendChild(creerEspacement(1, 'left'));// .lastChild : la Div qui contient des informations insérées provenant des Systèmes Tactiques
								x_trolls[j].childNodes[indexDesColonnes.Trolls.Guilde].lastChild.appendChild(cadreBarrePV);
								// détection de l'anomalie des PV max
								if ( parseInt(trollsDesST[i].PV.split('/')[0]) > parseInt(trollsDesST[i].PV.split('/')[1]) ) {
									// indication de l'anomalie au niveau de la cellule des PV
									var asterisque = document.createElement('div');
									asterisque.innerHTML = '*';
									asterisque.style.color = '#990000'; // rouge
									asterisque.style.fontSize = '24px';
									asterisque.align = 'right';
									asterisque.style.position = 'relative';
									asterisque.style.top = -4;
									asterisque.style.left = -1;
									barrePV.appendChild(asterisque);
									cadreBarrePV.title += '\r\n\r\nAnomalie détectée au niveau du nombre de PV max :\r\nVeuillez allez mettre à jour les Mouches et/ou l\'Equipement porté.';
								}
							}
							else {  
								// mise à jour des information concernant les PV, si nécessaire (la colonne PV n'a pas été ajoutée par ce script mais par MountyZilla)
								if ( ( x_trolls[j].childNodes[indexDesColonnes.Trolls.PV].firstChild.firstChild.title.split(' ')[0] != trollsDesST[i].PV ) && convertirDateEnMarqueurTemporel(x_trolls[j].childNodes[indexDesColonnes.Trolls.PV].firstChild.firstChild.title.split(' le ')[1], ' à ', '/') <= convertirDateEnMarqueurTemporel(trollsDesST[i].MAJ, ' ', '/') ) {
									// mise à jour de l'infobulle
									x_trolls[j].childNodes[indexDesColonnes.Trolls.PV].firstChild.firstChild.title = x_trolls[j].childNodes[indexDesColonnes.Trolls.PV].firstChild.firstChild.title.replace(x_trolls[j].childNodes[indexDesColonnes.Trolls.PV].firstChild.firstChild.title.split(' ')[0], trollsDesST[i].PV);
									// mise à jour de la barre de PV
									x_trolls[j].childNodes[indexDesColonnes.Trolls.PV].firstChild.firstChild.firstChild.width = Math.floor(100 * Math.min(trollsDesST[i].PV.split('/')[0], trollsDesST[i].PV.split('/')[1]) / trollsDesST[i].PV.split('/')[1] ); 
								}
								// détection de l'anomalie des PV max
								if ( parseInt(trollsDesST[i].PV.split('/')[0]) > parseInt(trollsDesST[i].PV.split('/')[1]) ) {
									// indication de l'anomalie au niveau de la cellule des PV
									var asterisque = document.createElement('div');
									asterisque.innerHTML = '*';
									asterisque.style.color = '#990000'; // rouge
									asterisque.style.fontSize = '18px';
									asterisque.style.height = 0; // 0 pour que le style.cssFloat = 'right' fonctionne correctement
									asterisque.style.cssFloat = 'right';
									asterisque.style.position = 'relative';
									asterisque.style.top = -13;
									asterisque.style.left = 2;
									asterisque.title = 'Anomalie détectée au niveau du nombre de PV max :\r\nVeuillez allez mettre à jour les Mouches et/ou l\'Equipement porté.';
									x_trolls[j].childNodes[indexDesColonnes.Trolls.PV].appendChild(asterisque);
									x_trolls[j].childNodes[indexDesColonnes.Trolls.PV].firstChild.firstChild.title += '\r\n\r\n' + asterisque.title;
								}
							}
							// ajout de l'information concernant les PA si il n'y a pas de colonne PA (ou si le Troll ajouté par le script BT_inside_MZ.user.js est issu d'un Système Tactique qui n'est pas celui utilisé par MZ)
							if ( indexDesColonnes.Trolls.PA == -1 || !x_trolls[j].childNodes[indexDesColonnes.Trolls.PA].innerHTML ) {
								// reprise/adaptation du code de MountyZilla utilisant les fonctions de MountyZilla
								/* PAs dispos */
								var span = document.createElement('span');
								span.title = 'jusqu\'au ' + trollsDesST[i].DLA.replace(' ', ' à ');
								span.style.cssFloat = 'left'; // sur la même ligne, à la suite
								appendText(span, trollsDesST[i].PA + ' PA' );
								// coloration du nombre de PA en fonction de la possibilité d'agir ou non
								if ( trollsDesST[i].PA != '0' || convertirDateEnMarqueurTemporel(trollsDesST[i].DLA, ' ', '/') < marqueurTemporel() ) {
									// le Troll peut agir (il a au moins 1 PA de disponible, ou sa DLA est dépassée et il peut activer)
									span.style.color = couleurJouable;
								}
								else {
									// le Troll ne peut pas agir
									span.style.color = couleurNonJouable;
								}
								// ajout du nombre de PA dans la colonne "Guilde"
								x_trolls[j].childNodes[indexDesColonnes.Trolls.Guilde].lastChild.appendChild(creerEspacement(1, 'left'));// .lastChild : la Div qui contient des informations insérées provenant des Systèmes Tactiques
								x_trolls[j].childNodes[indexDesColonnes.Trolls.Guilde].lastChild.appendChild(span);
								x_trolls[j].childNodes[indexDesColonnes.Trolls.Guilde].lastChild.appendChild(creerEspacement(1, 'right'));
							}
							else {
								// coloration du nombre de PA en fonction de la possibilité d'agir ou non
								if ( x_trolls[j].childNodes[indexDesColonnes.Trolls.PA].firstChild.innerHTML != '0 PA' || convertirDateEnMarqueurTemporel(x_trolls[j].childNodes[indexDesColonnes.Trolls.PA].firstChild.title.replace('le ', ''), ' à ', '/') < marqueurTemporel() ) {
									// le Troll peut agir (il a au moins 1 PA de disponible, ou sa DLA est dépassée et il peut activer)
									x_trolls[j].childNodes[indexDesColonnes.Trolls.PA].firstChild.style.color = couleurJouable;
								}
								else {
									// le Troll ne peut pas agir
									x_trolls[j].childNodes[indexDesColonnes.Trolls.PA].firstChild.style.color = couleurNonJouable;
								}
							}						
							
							// ajout de la puce représentant la durée écoulée depuis la dernière mise-à-jour des informations de la ligne
							if ( indexDesColonnes.Trolls.PV == -1 || !x_trolls[j].childNodes[indexDesColonnes.Trolls.PV].innerHTML) {
								// si il n'y a pas de colonne PV (ou si le Troll ajouté par le script BT_inside_MZ.user.js est issu d'un Système Tactique qui n'est pas celui utilisé par MZ)
								var origineInfo = 'BT_inside';
								var indiceNodePV = 3; // indice par défaut, en absence de l'image "Invisible" ou "Camouflé"
								if ( x_trolls[j].childNodes[indexDesColonnes.Trolls.Guilde].lastChild.childNodes[4].outerHTML.indexOf(' le ') != -1 ) {
									indiceNodePV = 4; // indice en présence de l'image "Invisible" ou "Camouflé"
								}
								var	dateInfo = x_trolls[j].childNodes[indexDesColonnes.Trolls.Guilde].lastChild.childNodes[indiceNodePV].title.split('\r\n\r\n')[0].split(' le ')[1];
							}
							else {
								// sinon
								var origineInfo = x_trolls[0].childNodes[indexDesColonnes.Trolls.PV].getAttribute('origine');		
								var	dateInfo = x_trolls[j].childNodes[indexDesColonnes.Trolls.PV].firstChild.firstChild.title.split('\r\n\r\n')[0].split(' le ')[1];
								
								if ( x_trolls[0].childNodes[indexDesColonnes.Trolls.PA].innerHTML == '<b>PA</b>' ) {
									x_trolls[0].childNodes[indexDesColonnes.Trolls.PA].width = '43';
								}									
							}
							// analyse du temps écoulé depuis l'information la plus anciennes
							var urlIcone = urlIconeAffichageInfo;
							var titreIcone = 'Ces informations sont dépassées, ' + (( origineInfo == 'BT_inside' ) ? 'elles' : 'certaines') + ' datent de plus de ' + dureeInfoTrollsPerimees + ' heure' + ( dureeInfoTrollsPerimees >= 2 ? 's' : '' ) + '.\r\nCliquez pour aller les mettre à jour.';
							var lienIcone = 'http://trolls.ratibus.net/' + trollsDesST[i].SystemeTactique + '/index.php?id_g=' + trollsDesST[i].ReferenceGroupe;
							if ( ( marqueurTemporel() - convertirDateEnMarqueurTemporel(dateInfo, ' à ', '/') < dureeInfoTrollsRecentes * 3600 ) && ( marqueurTemporel() - convertirDateEnMarqueurTemporel(trollsDesST[i].MAJ, ' ', '/') < dureeInfoTrollsRecentes * 3600 ) ) { // N * 3600 secondes = N heure(s)
								urlIcone = urlIconeInfoRecentes;
								titreIcone = 'Ces informations sont récentes, elles datent ' + (( origineInfo == 'BT_inside' ) ? '' : 'toutes ') + 'de moins de ' + dureeInfoTrollsRecentes + ' heure' + ( dureeInfoTrollsRecentes >= 2 ? 's' : '' ) + '.';
								lienIcone = '';
							}
							else if ( ( marqueurTemporel() - convertirDateEnMarqueurTemporel(dateInfo, ' à ', '/') < dureeInfoTrollsAnciennes * 3600 ) && ( marqueurTemporel() - convertirDateEnMarqueurTemporel(trollsDesST[i].MAJ, ' ', '/') < dureeInfoTrollsAnciennes * 3600 ) ) { // N * 3600 secondes = N heure(s)
								urlIcone = urlIconeInfoAnciennes;
								titreIcone = 'Ces informations ne sont plus très récentes, ' + (( origineInfo == 'BT_inside' ) ? 'elles' : 'certaines') + ' datent de plus de ' + dureeInfoTrollsRecentes + ' heure' + ( dureeInfoTrollsRecentes >= 2 ? 's' : '' ) + '.\r\nCliquez pour aller les mettre à jour.';
							}
							else if ( ( marqueurTemporel() - convertirDateEnMarqueurTemporel(dateInfo, ' à ', '/') < dureeInfoTrollsPerimees * 3600 ) && ( marqueurTemporel() - convertirDateEnMarqueurTemporel(trollsDesST[i].MAJ, ' ', '/') < dureeInfoTrollsPerimees * 3600 ) ) { // N * 3600 secondes = N heure(s)
								urlIcone = urlIconeInfoPerimees;
								titreIcone = 'Ces informations peuvent être dépassées, ' + (( origineInfo == 'BT_inside' ) ? 'elles' : 'certaines') + ' datent de plus de ' + dureeInfoTrollsAnciennes + ' heure' + ( dureeInfoTrollsAnciennes >= 2 ? 's' : '' ) + '.\r\nCliquez pour aller les mettre à jour.';
							}
							// ajout de la puce
							var unLien = document.createElement( lienIcone != '' ? 'a' : 'span' );
							unLien.href = lienIcone;
							unLien.target = '_blank';
							unLien.style.cssFloat = 'right';
							unLien.style.position = 'relative';
							unLien.style.top = 1;
							var uneImage = document.createElement('img');
							uneImage.src = urlIcone;
							uneImage.title = titreIcone;
							uneImage.align = 'absmiddle';
							unLien.appendChild(uneImage);
							if ( indexDesColonnes.Trolls.PV == -1 || !x_trolls[j].childNodes[indexDesColonnes.Trolls.PV].innerHTML) {
								// si il n'y a pas de colonne PV (ou si le Troll ajouté par le script BT_inside_MZ.user.js est issu d'un Système Tactique qui n'est pas celui utilisé par MZ)
								x_trolls[j].childNodes[indexDesColonnes.Trolls.Guilde].lastChild.appendChild(creerEspacement(1));// .lastChild : la Div qui contient des informations insérées provenant des Systèmes Tactiques
								x_trolls[j].childNodes[indexDesColonnes.Trolls.Guilde].lastChild.appendChild(unLien);
							}
							else {
								// sinon
								x_trolls[j].childNodes[indexDesColonnes.Trolls.PA].appendChild(creerEspacement(1));
								x_trolls[j].childNodes[indexDesColonnes.Trolls.PA].appendChild(unLien);
							}

							// sortie de la boucle puisque le Troll a été trouvé et sa ligne modifiée
							break;
						}
					}
				}
				
				// modification de la case à cocher "Diplomatie" pour pouvoir gérer correctement la coloration des lignes des Trolls des Systèmes Tactiques
				//if ( trollsDesST.length > 0 ) {
// TEMP					
				if ( trollsDesST.length > 0 && checkBoxDiplo) {
// /TEMP
					checkBoxDiplo.addEventListener('click', attendreDiplomatiePuisColorerLignesTrollsDesST, true);
				}
				// coloration des lignes des Trolls des Systèmes Tactiques, nécessaire si la case "Effacer La Diplo" est cochée avant d'afficher la Vue
				attendreDiplomatiePuisColorerLignesTrollsDesST();
			}
			
			
			// compile si nécessaire les informations des Suivants récupérées depuis les Systèmes Tactiques des Bricol'Trolls
			if ( compileInformationsSuivantsBT() ) {
				// ajout dans la vue MountyHall des informations compilées
				for (var i=0;i<suivantsDesST.length;i++) {
					for (var j=1;j<x_monstres.length;j++) {
						if ( suivantsDesST[i].ReferenceSuivant == x_monstres[j].childNodes[indexDesColonnes.Monstres.Reference].innerHTML ) {
							// coloration des lignes de Suivants en fonction de leurs propriétaires
							var couleur = ( suivantsDesST[i].ReferenceTroll == numTroll ) ? couleurLigneSuivantsPerso : couleurLigneSuivants;
							for (var k=0;k<x_monstres[j].childNodes.length;k++) {
								x_monstres[j].childNodes[k].style.backgroundColor = couleur;
							}
							// si la colonne Niveau est présente et qu'une couleur a bien été appliquée à la ligne, redéfinition des ajouts fait par MountyZilla, pour ne plus utiliser les classes CSS et ajout d'écouteurs d'événement
							if ( !checkBoxLevels.checked && x_monstres[j].childNodes[indexDesColonnes.Monstres.Reference].style.backgroundColor ) {
								x_monstres[j].childNodes[indexDesColonnes.Monstres.Niveau].setAttribute('onmouseover', 'this.style.cursor = \'pointer\';');
								x_monstres[j].childNodes[indexDesColonnes.Monstres.Niveau].addEventListener('mouseover', assombrirCouleur, true);
								x_monstres[j].childNodes[indexDesColonnes.Monstres.Niveau].setAttribute('onmouseout', '');
								x_monstres[j].childNodes[indexDesColonnes.Monstres.Niveau].addEventListener('mouseout', eclaircirCouleur, true);
							}
							// ajout d'un écouteur d'événement sur la case à cocher "Effacer Les Niveaux" pour pouvoir appliquer le style des lignes lors du réaffichage de la colonne Niveau 						
							checkBoxLevels.addEventListener('click', onClickNiveau, true);
							
							// ajout dans la colonne Nom du propriétaire et de la puce représentant la durée écoulée depuis la dernière mise-à-jour des informations de la ligne
							var uneDiv = document.createElement('div');
							// pour les suivants appartenant aux autres Trolls des Systèmes Tactiques
							if ( suivantsDesST[i].ReferenceTroll != numTroll ) {
								// affichage du texte [Suivant de ...]
								uneDiv.innerHTML = '<font size="1">[suivant de ' + suivantsDesST[i].NomTroll + ']</font>';
							}
							// pour les suivants personnels
							else {
								// affichage d'un lien [mon suivant] redirigeant vers la page du suivant
								var unLien = document.createElement('a');
								unLien.href = '/mountyhall/MH_Follower/FO_Profil.php?ai_IdFollower=' + suivantsDesST[i].ReferenceSuivant;
								unLien.innerHTML = '<font size="1">[mon suivant]</font>';
								uneDiv.appendChild(unLien);
							}
							uneDiv.style.cssFloat = 'left';
							var uneAutreDiv = document.createElement('div');
							uneAutreDiv.appendChild(creerEspacement(1, 'left'));
							uneAutreDiv.appendChild(uneDiv);
							uneAutreDiv.appendChild(creerEspacement(1, 'left'));
							x_monstres[j].childNodes[indexDesColonnes.Monstres.Nom].appendChild(uneAutreDiv);
							// gestion de l'affichage de la fenêtre d'information au survol du texte
							uneDiv.id = 'suivant_' + i;
							uneDiv.addEventListener('mouseover', afficherInfos, true);
							uneDiv.addEventListener('mouseout', cacherInfos, true);
							
							// analyse du temps écoulé depuis la dernière mise à jour
							var urlIcone = urlIconeAffichageInfo;
							var titreIcone = 'Ces informations sont dépassées, elles datent de plus de ' + dureeInfoSuivantsPerimees + ' heure' + ( dureeInfoSuivantsPerimees >= 2 ? 's' : '' ) + '.\r\nCliquez pour aller les mettre à jour.';
							var lienIcone = 'http://trolls.ratibus.net/' + suivantsDesST[i].SystemeTactique + '/gowaps_tanieres.php?id_g=' + suivantsDesST[i].ReferenceGroupe;
							if ( marqueurTemporel() - convertirDateEnMarqueurTemporel(suivantsDesST[i].MAJ, ' ', '/') < dureeInfoSuivantsRecentes * 3600 ) { // N * 3600 secondes = N heure(s)
								urlIcone = urlIconeInfoRecentes;
								titreIcone = 'Ces informations sont récentes, elles datent de moins de ' + dureeInfoSuivantsRecentes + ' heure' + ( dureeInfoSuivantsRecentes >= 2 ? 's' : '' ) + '.';
								lienIcone = '';
							}
							else if ( marqueurTemporel() - convertirDateEnMarqueurTemporel(suivantsDesST[i].MAJ, ' ', '/') < dureeInfoSuivantsAnciennes * 3600 ) { // N * 3600 secondes = N heure(s)
								urlIcone = urlIconeInfoAnciennes;
								titreIcone = 'Ces informations ne sont plus très récentes, elles datent de plus de ' + dureeInfoSuivantsRecentes + ' heure' + ( dureeInfoSuivantsRecentes >= 2 ? 's' : '' ) + '.\r\nCliquez pour aller les mettre à jour.';
							}
							else if ( marqueurTemporel() - convertirDateEnMarqueurTemporel(suivantsDesST[i].MAJ, ' ', '/') < dureeInfoSuivantsPerimees * 3600 ) { // N * 3600 secondes = N heure(s)
								urlIcone = urlIconeInfoPerimees;
								titreIcone = 'Ces informations peuvent être dépassées, elles datent de plus de ' + dureeInfoSuivantsAnciennes + ' heure' + ( dureeInfoSuivantsAnciennes >= 2 ? 's' : '' ) + '.\r\nCliquez pour aller les mettre à jour.';
							}
							// ajout de la puce
							var unLien = document.createElement( lienIcone != '' ? 'a' : 'span' );
							unLien.href = lienIcone;
							unLien.target = '_blank';
							var uneImage = document.createElement('img');
							uneImage.src = urlIcone;
							uneImage.title = titreIcone;
							uneImage.align = 'absmiddle';
							unLien.appendChild(uneImage);
							x_monstres[j].childNodes[indexDesColonnes.Monstres.Nom].lastChild.appendChild(unLien);
							x_monstres[j].childNodes[indexDesColonnes.Monstres.Nom].lastChild.appendChild(creerEspacement(1, 'right'));
							x_monstres[j].childNodes[indexDesColonnes.Monstres.Nom].lastChild.style.cssFloat = 'right';
							// sortie de la boucle puisque le Suivant a été trouvé et sa ligne modifiée
							break;
						}
					}
				}
				// création de la bulle d'information qui apparaît au survol du propriétaire du Suivant
				creerInfos();
			}
		}
		
		// suppression des informations du localStorage
		window.localStorage.removeItem('BT_inside_MZ_constantes');
		window.localStorage.removeItem('BT_inside_MZ_infoTrolls');
		window.localStorage.removeItem('BT_inside_MZ_infoSuivants');
	}
	catch (e) {
		window.alert('BT_inside_Tout_MZ.user.js MountyHall Vue : ' + e.message);
	}
}
 
 
 
// *** Assombrit la couleur de fond de l'élément sur lequel un événement appelle cette fonction ***
function assombrirCouleur() {
	modifierCouleur.call(this, -30); // transfert du contexte "this"
}


// *** Eclaircit la couleur de fond de l'élément sur lequel un événement appelle cette fonction ***
function eclaircirCouleur() {
	modifierCouleur.call(this, 30); // transfert du contexte "this"
}


// *** modifie la couleur de fond de l'élément passé en paramètre avec la valeur passée en paramètre ***
function modifierCouleur(valeurModification) {
	// reprise/adaptation du code du script reorgVue2.js par Raistlin
	var couleurDeFond = this.style.backgroundColor ? this.style.backgroundColor : this.parentNode.style.backgroundColor;
	var couleursRGB = couleurDeFond.replace(/rgb\(|\)/g, '').split(',');    
	couleursRGB[0] = parseInt(couleursRGB[0], 10) + valeurModification;
	couleursRGB[1] = parseInt(couleursRGB[1], 10) + valeurModification;
	couleursRGB[2] = parseInt(couleursRGB[2], 10) + valeurModification;
	this.style.backgroundColor = 'rgb(' + couleursRGB[0]+ ',' + couleursRGB[1] + ',' + couleursRGB[2] + ')';
}
 

// *** retourne un marqueur temporel correspondant à l'instant présent, en secondes depuis le 01-01-1970 ***
 function marqueurTemporel() {
	try {
		// marqueur temporel getTime() en millisecondes, converti en secondes et arrondi
		return Math.round(new Date().getTime() / 1000);
	}
	catch (e) {
		window.alert('BT_inside_Tout_MZ.user.js marqueurTemporel() : ' + e.message);
	}		
 }
 
 
 // *** retourne la date passée en paramètre (format 'DD/MM/YYYY HH:mm:ss') convertie en marqueur temporel, en secondes depuis le 01-01-1970 ***
 function convertirDateEnMarqueurTemporel(dateAConvertir, separateur1, separateur2) {
	try {
		// le separateur1 délimite la date et l'heure. Le separateur2 délimite le jour, le mois et l'année qui sont inversés
		return new Date( dateAConvertir.split(separateur1)[0].split(separateur2).reverse().join('-') + 'T' + dateAConvertir.split(separateur1)[1] ).getTime() / 1000;
	}
	catch (e) {
		window.alert('BT_inside_Tout_MZ.user.js convertirDateEnMarqueurTemporel() : ' + e.message);
	}		
 }
 
 
// *** vérifie la date de la dernière récupération d'information depuis les Systèmes Tactiques des Bricol'Trolls et extrait les informations des Trolls si nécessaire ***
 function compileInformationsTrollsBT(referenceTroll) {
	try {
		// récupération des informations sauvegardées par le script BT_inside_MZ.user.js pour le Troll connecté
		var informationsTrollsBT = decoderASCII(window.localStorage.BT_inside_MZ_infoTrolls);
		// découpage par Système Tactique
		var listeST = informationsTrollsBT.split('/#');
		var suiteTrollsTraites = '';
		trollsDesST.length = 0;
		for (var i=0;i<listeST.length-1;i++) {
			// si le Troll connecté appartient au Système Tactique traité, il faut tenir compte de ces informations 
			if ( listeST[i].indexOf(referenceTroll) != -1 ) {
				// ajout du Système Tactiques dans la suite des Systèmes Tactiques auxquels appartient le Troll connecté (liste utilisée par la suite pour savoir quels Suivants peut reconnaître le Troll connecté)
				suiteSTaccessibles += ';' + listeST[i].substr(listeST[i].indexOf('#')+1, listeST[i].indexOf(';')-1) + ';';
				// transfert des informations dans le tableau des Trolls des Systèmes Tactiques : trollsDesST
				var listeTrolls = listeST[i].split('@');
				for (var j=1;j<listeTrolls.length-1;j++) {
					var lesDonnees = listeTrolls[j].split(';');
					// si un Troll est présent dans plusieurs Systèmes Tactiques alors seules les informations du dernier Système Tactique visité sont prises en compte : pour cela les informations les plus récentes doivent être en premier dans 'informationsTrollsBT'
					if ( suiteTrollsTraites.indexOf(';' + lesDonnees[0] + ';') == -1 ) {	
						trollsDesST.push({Reference: lesDonnees[0], Nom: lesDonnees[1], Statut: lesDonnees[2], Niveau: lesDonnees[3], Race: lesDonnees[4], Fatigue: lesDonnees[5], SystemeTactique: lesDonnees[6], ReferenceGroupe: lesDonnees[7], NomGroupe: lesDonnees[8], Visibilite: lesDonnees[9], PV: lesDonnees[10], CouleurBarrePV: lesDonnees[11], MAJ: lesDonnees[12], PA: lesDonnees[13], DLA: lesDonnees[14], X: lesDonnees[15], Y: lesDonnees[16], N: lesDonnees[17]});
						// ajout du Troll dans la suite des Trolls déjà traités
						suiteTrollsTraites += ';' + lesDonnees[0] + ';';
					}
				}
			}
		}
		return true;
	}
	catch (e) {
		window.alert('BT_inside_Tout_MZ.user.js compileInformationsTrollsBT() : ' + e.message);
	}		
 }
 

 // *** récupération des information des Suivants issues des Systèmes Tactiques des Bricol'Trolls ***
 function compileInformationsSuivantsBT() {
	try {
		// récupération des informations sauvegardées par le script BT_inside_MZ.user.js pour les Systèmes Tactiques du Troll connecté
		var informationsSuivantsBT = decoderASCII(window.localStorage.BT_inside_MZ_infoSuivants);
		if ( informationsSuivantsBT == '' ) { 
			return false;
		}
		// découpage par Système Tactique
		var listeST = informationsSuivantsBT.split('/#');
		var suiteSuivantsTraites = '';
		suivantsDesST.length = 0;
		for (var i=0;i<listeST.length-1;i++) {
			// si le Troll connecté appartient au Système Tactique traité, il faut tenir compte de ces informations 
			if ( suiteSTaccessibles.indexOf(';' + listeST[i].substr(listeST[i].indexOf('#')+1, listeST[i].indexOf(';')-1) + ';') != -1 ) {
				// transfert des informations dans le tableau des Suivants des Systèmes Tactiques : suivantsDesST
				var listeSuivants = listeST[i].split('@');
				for (var j=1;j<listeSuivants.length-1;j++) {
					var lesDonnees = listeSuivants[j].split(';');
					// si un Suivant est présent dans plusieurs Systèmes Tactiques alors seules les informations du dernier Système Tactique visité sont prises en compte : pour cela les informations les plus récentes doivent être en premier dans 'informationsSuivantsBT')
					if ( suiteSuivantsTraites.indexOf(';' + lesDonnees[0] + ';') == -1 ) {	
						suivantsDesST.push({ReferenceSuivant: lesDonnees[0], ReferenceTroll: lesDonnees[1], NomTroll: lesDonnees[2], SystemeTactique: lesDonnees[3], ReferenceGroupe: lesDonnees[4], MAJ: lesDonnees[5], Infos: lesDonnees[6], Equipement: lesDonnees[7], X: lesDonnees[8], Y: lesDonnees[9], N: lesDonnees[10]});
						// ajout du Suivant dans la suite des Suivants déjà traités
						suiteSuivantsTraites += ';' + lesDonnees[0] + ';';
					}
				}
			}
		}
		return true;
	}
	catch (e) {
		window.alert('BT_inside_Tout_MZ.user.js compileInformationsSuivantsBT() : ' + e.message);
	}		
 }

 
// *** teste régulièrement si la Diplomatie a été récupérée par MountyZilla *** 
function attendreDiplomatiePuisColorerLignesTrollsDesST() {
	try {
		// création d'une fonction régulièrement exécutée
		var fonctionRegulierementExecutee =	window.setInterval(function() {
			// teste si la Diplomatie a été récupérée ou si MountyZilla n'a pas à récupérer la Diplomatie (c'est-à-dire si la case "Effacer La Diplo" est cochée) 
			//if ( !isDiploRaw || checkBoxDiplo.checked ) {
// TEMP
			if ( !isDiploRaw || (checkBoxDiplo && checkBoxDiplo.checked) ) {
// /TEMP
				// la Diplomatie a été récupérée par MoutyZilla, il faut arrêter l'exécution régulière de la fonction 
				window.clearInterval(fonctionRegulierementExecutee);
				// puis il faut colorer les lignes des Trolls des Systèmes Tactiques
				for (var j=1;j<x_trolls.length;j++) {
					// détection des lignes à colorer (celles ayant l'attribut "cible", Trolls dans la vue MountyHall, et celles ayant l'attribut "origine", Trolls [hors-vue])
					if ( x_trolls[j].firstChild.getAttribute('cible') == 'BT_inside' || x_trolls[j].firstChild.getAttribute('origine') == 'BT_inside' ) {
						var couleur = ( x_trolls[j].firstChild.getAttribute('cible') == 'BT_inside' ) ? couleurLigneTrolls : couleurLigneTrollsHorsVue;
						for (var k=0;k<x_trolls[j].childNodes.length;k++) {
							x_trolls[j].childNodes[k].style.backgroundColor = couleur;
						}
					}
				}
			}
		}, 200); // fréquence d'exécution en millisecondes
	}
	catch (e) {
		window.alert('BT_inside_Tout_MZ.user.js appliquerColorationLignesTrollsDesST() : ' + e.message);
	}		
}


// *** applique la gestion de la coloration des lignes des Suivants des Systèmes Tactiques sur la colonne Niveau à l'affichage de celle-ci (c'est-à-dire lorsque l'on coche la case à cocher) ***
function onClickNiveau() {
	if ( !checkBoxLevels.checked ) {
		for (var i=1;i<x_monstres.length;i++) {
			// si une couleur a bien été appliquée à la ligne par ce script
			if ( x_monstres[i].childNodes[indexDesColonnes.Monstres.Reference].style.backgroundColor ) {
				// reprise de la coloration
				x_monstres[i].childNodes[indexDesColonnes.Monstres.Niveau].style.backgroundColor = x_monstres[i].childNodes[indexDesColonnes.Monstres.Reference].style.backgroundColor;
				// redéfinition des ajouts fait par MountyZilla pour ne plus utiliser les classes CSS, et ajout d'écouteurs d'événements
				x_monstres[i].childNodes[indexDesColonnes.Monstres.Niveau].setAttribute('onmouseover', 'this.style.cursor = \'pointer\';');
				x_monstres[i].childNodes[indexDesColonnes.Monstres.Niveau].addEventListener('mouseover', assombrirCouleur, true);
				x_monstres[i].childNodes[indexDesColonnes.Monstres.Niveau].setAttribute('onmouseout', '');
				x_monstres[i].childNodes[indexDesColonnes.Monstres.Niveau].addEventListener('mouseout', eclaircirCouleur, true);
			}	
		}
	}
}


// *** applique la gestion de la coloration des lignes des Trolls des Systèmes Tactiques sur la colonne de cases à cocher à l'affichage de celle-ci (c'est-à-dire lorsque l'on clique sur le "Envoyer...") ***
function onClickSend() {
	// si la colonne de cases à cocher existe
	if ( document.getElementById('envoi1') ) {
		for (var i=1;i<x_trolls.length;i++) {
			// si une couleur a bien été appliquée à la ligne par ce script
			if ( x_trolls[i].childNodes[indexDesColonnes.Trolls.Reference].style.backgroundColor ) {
				// reprise de la coloration sur la nouvelle colonne de cases à cocher, insérée en tant que quatrième colonne
				x_trolls[i].childNodes[3].style.backgroundColor = x_trolls[i].childNodes[indexDesColonnes.Trolls.Reference].style.backgroundColor;
			}	
		}
	}
}


// *** Création de la fenêtre d'informations, qui apparaîtra au survol d'un Suivant ***
function creerInfos() {
	fenetreInfo = document.createElement('div');
	fenetreInfo.className = 'mh_textbox';
	fenetreInfo.setAttribute('style', 'position: absolute; border: 1px solid #000000; visibility: hidden; display: inline; z-index: 3; padding: 5px; min-width: 450px;');
	document.body.appendChild(fenetreInfo);
}


// *** Renseigne le contenu de la fenêtre d'informations en fonction du Suivant survolé et la rend visible ***
function afficherInfos(evt) {
	var i = this.getAttribute('id').substr(this.getAttribute('id').indexOf('_')+1, this.getAttribute('id').length);
	fenetreInfo.innerHTML = '<center>' + suivantsDesST[i].Infos.replace(' : ', ' : jusqu\'au ').replace(/(\d) (\d)/, '$1 à $2') + '</center><hr />le ' + suivantsDesST[i].MAJ.replace(' ', ' à ') + ' : ' + suivantsDesST[i].Equipement.replace('<li>', '<font size="1"><li>') + '</font>';
	fenetreInfo.style.left = Math.min(evt.pageX + 15, window.innerWidth - 500) + 'px';
	fenetreInfo.style.top = evt.pageY + 15 + 'px';
	fenetreInfo.style.visibility = 'visible';
}


// *** Rend invisible la fenêtre d'informations ***
function cacherInfos() {
	fenetreInfo.style.visibility = 'hidden';
}

// *** Crée un espacement ***
function creerEspacement(nombreEspaces, cssFloat) {
	var unEspacement = document.createElement('span');
	for (var i=0;i<nombreEspaces;i++) {
		unEspacement.innerHTML += '&nbsp;';
	}
	// si un paramètre cssFloat est fourni alors il est utilisé
	if (cssFloat) {
		unEspacement.style.cssFloat = cssFloat; // 'left' = sur la même ligne, à la suite; 'right' = sur la même ligne, collé à droite
	}
	return unEspacement;
}

// *** décode une suite de code ASCII en texte ***
function decoderASCII(texteEncode) {
	// si aucun texte à traiter, alors on retourne une chaîne vide
	if ( !texteEncode ) return '';

	// chaque code ASCII du texte passé en paramètre est remplacé par le caractère correspondant
	var texte = '';
	var caracteres = texteEncode.replace(/\|0\|/g, '|').split('|');
	for (var i=0;i<caracteres.length;i++) {
		texte += String.fromCharCode(caracteres[i]);
	}
	return texte;
}